@@ -1,3 +1,27 @@
+/*!
+This crate is contains common test cases for Atelier readers and writers.
+*/
+
+#![warn(
+    // ---------- Stylistic
+    future_incompatible,
+    nonstandard_style,
+    rust_2018_idioms,
+    trivial_casts,
+    trivial_numeric_casts,
+    // ---------- Public
+    missing_debug_implementations,
+    missing_docs,
+    unreachable_pub,
+    // ---------- Unsafe
+    unsafe_code,
+    // ---------- Unused
+    unused_extern_crates,
+    unused_import_braces,
+    unused_qualifications,
+    unused_results,
+)]
+
 use atelier_core::io::lines::make_line_oriented_form;
 use atelier_core::io::{read_model_from_file, read_model_from_string, ModelReader};
 use atelier_core::model::Model;
@@ -9,11 +33,19 @@ use std::path::{Path, PathBuf};
 // Public Types
 // ------------------------------------------------------------------------------------------------
 
+///
 /// A Type that represents the result of the `LineOrientedWriter` output.
+///
 pub type ExpectedLines = Vec<&'static str>;
 
+///
+/// A model that should match the expected lines in `LineOrientedWriter` format.
+///
+#[derive(Clone, Debug)]
 pub struct TestCaseModel {
+    /// The model to write
     pub model: Model,
+    /// The expected result.
     pub expected_lines: ExpectedLines,
 }
 
@@ -30,6 +62,10 @@ const LINE_ENDING: &str = "\n";
 // Public Functions
 // ------------------------------------------------------------------------------------------------
 
+///
+/// Parse a model from the string `input_str`, using the `reader` representation implementation, and then
+/// compare to the `expected` model value.
+///
 pub fn parse_and_compare_model(input_str: &str, reader: &mut impl ModelReader, expected: Model) {
     println!("input to parse:\n{}", input_str);
     horizontal_line();
@@ -42,6 +78,10 @@ pub fn parse_and_compare_model(input_str: &str, reader: &mut impl ModelReader, e
     }
 }
 
+///
+/// Parse the file in `actual_path`, using the `reader` representation implementation, and then
+/// compare to the line-oriented representation in `expected_path`.
+///
 pub fn parse_and_compare_to_files(
     reader: &mut impl ModelReader,
     actual_path: &Path,
@@ -56,18 +96,30 @@ pub fn parse_and_compare_to_files(
     }
 }
 
-pub fn parse_and_compare_to_file(input_str: &str, reader: &mut impl ModelReader, file_path: &Path) {
+///
+/// Parse a model from the string `input_str`, using the `reader` representation implementation, and then
+/// compare to the line-oriented representation in `expected_path`.
+///
+pub fn parse_and_compare_to_file(
+    input_str: &str,
+    reader: &mut impl ModelReader,
+    expected_path: &Path,
+) {
     horizontal_line();
     match read_model_from_string(reader, input_str) {
         Ok(actual) => {
             horizontal_line();
-            compare_model_to_file(actual, file_path);
+            compare_model_to_file(actual, expected_path);
         }
         Err(err) => panic!("error: {:#?}", err),
     }
 }
 
-pub fn compare_model_to_file(model: Model, file_path: &Path) {
+///
+/// Serialize `model` in the line-oriented representation and compare to the expected value in
+/// `expected_path`.
+///
+pub fn compare_model_to_file(model: Model, expected_path: &Path) {
     let actual_lines: Vec<String> = make_line_oriented_form(&model)
         .iter()
         .map(|s| {
@@ -82,7 +134,7 @@ pub fn compare_model_to_file(model: Model, file_path: &Path) {
         })
         .collect();
 
-    let expected_lines: Vec<String> = fs::read_to_string(file_path)
+    let expected_lines: Vec<String> = fs::read_to_string(expected_path)
         .unwrap()
         .split(LINE_ENDING)
         .map(|s| {
@@ -98,18 +150,11 @@ pub fn compare_model_to_file(model: Model, file_path: &Path) {
     assert_eq!(actual_lines, expected_lines);
 }
 
-// ------------------------------------------------------------------------------------------------
-// Implementations
-// ------------------------------------------------------------------------------------------------
-
-// ------------------------------------------------------------------------------------------------
-// Private Functions
-// ------------------------------------------------------------------------------------------------
-
 #[inline]
 fn horizontal_line() {
     println!("------------------------------------------------------------------------------------------------");
 }
+
 // ------------------------------------------------------------------------------------------------
 // Modules
 // ------------------------------------------------------------------------------------------------
